b16_display

Function b16_display 

pub fn b16_display<T: AsRef<[u8]>>(input: T) -> String
Applies the hexadecimal-encoding scheme to some data but only returns the first eight characters.

Can be used to print a hash to console.

Note: The output of this function cannot be decoded again, since we remove a relevant portion of the information!