Module traits

Module traits 

Simple traits that are based on the Hash256 type

Traits

Hashable
The Hashable trait indicates, that we can generate a Hash256 from this type.
Hashed
The Hashed trait indicates, that the hash over some data was already calculated and saved.